@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # vim:et sts=4 sw=4
 #
 # ibus-typing-booster - A completion input method for IBus
@@ -328,13 +327,14 @@ class SoundObject:
         if not self._aplay_binary:
             return
         try:
-            self._aplay_process = subprocess.Popen('aplay', shell=False,
-                                                   stdin=subprocess.PIPE,
-                                                   stderr=subprocess.PIPE,
-                                                   stdout=subprocess.PIPE,
-                                                   encoding=None,
-                                                   errors=None,
-                                                   text=None)
+            self._aplay_process = subprocess.Popen( # pylint: disable=consider-using-with
+                'aplay', shell=False,
+                stdin=subprocess.PIPE,
+                stderr=subprocess.PIPE,
+                stdout=subprocess.PIPE,
+                encoding=None,
+                errors=None,
+                text=None)
         except (OSError, ValueError) as error:
             LOGGER.exception(
                 'cannot start aplay process %s: %s',
